summaryrefslogtreecommitdiff
path: root/source
diff options
context:
space:
mode:
authorRobert Moore <Robert.Moore@intel.com>2017-10-05 12:56:47 -0700
committerRobert Moore <Robert.Moore@intel.com>2017-10-05 12:56:47 -0700
commitb2858b2cc83e1481950a2c976f62d4e1d758bc85 (patch)
tree586c41597d9494930680c5b975285c973b1886fb /source
parentea593f62d0aff7248c6c1a29548a13fd30307a78 (diff)
downloadacpica-b2858b2cc83e1481950a2c976f62d4e1d758bc85.tar.gz
Update output from ACPI_EXCEPTION macro
Changes line prefix from "ACPI Exception" to simply "ACPI Error" to match the ACPI_ERROR macro. ACPI_EXCEPTION takes the ACPI status as an argument, decodes and displays it along with the error message.
Diffstat (limited to 'source')
-rw-r--r--source/components/utilities/utxferror.c8
-rw-r--r--source/include/acutils.h3
2 files changed, 4 insertions, 7 deletions
diff --git a/source/include/acutils.h b/source/include/acutils.h
index 0a645508f..4e81856ae 100644
--- a/source/include/acutils.h
+++ b/source/include/acutils.h
@@ -227,9 +227,6 @@ extern const char *AcpiGbl_PtypDecode[];
#ifndef ACPI_MSG_ERROR
#define ACPI_MSG_ERROR "ACPI Error: "
#endif
-#ifndef ACPI_MSG_EXCEPTION
-#define ACPI_MSG_EXCEPTION "ACPI Exception: "
-#endif
#ifndef ACPI_MSG_WARNING
#define ACPI_MSG_WARNING "ACPI Warning: "
#endif
diff --git a/source/components/utilities/utxferror.c b/source/components/utilities/utxferror.c
index a81352b93..95cb4509e 100644
--- a/source/components/utilities/utxferror.c
+++ b/source/components/utilities/utxferror.c
@@ -214,8 +214,8 @@ ACPI_EXPORT_SYMBOL (AcpiError)
*
* RETURN: None
*
* DESCRIPTION: Print "ACPI Exception" message with module/line/version info
* and decoded ACPI_STATUS.
*
******************************************************************************/
@@ -236,12 +236,12 @@ AcpiException (
if (ACPI_SUCCESS (Status))
{
- AcpiOsPrintf (ACPI_MSG_EXCEPTION);
+ AcpiOsPrintf (ACPI_MSG_ERROR);
}
else
{
- AcpiOsPrintf (ACPI_MSG_EXCEPTION "%s, ",
+ AcpiOsPrintf (ACPI_MSG_ERROR "%s, ",
AcpiFormatException (Status));
}
@@ -214,8 +214,8 @@ ACPI_EXPORT_SYMBOL (AcpiError)
* RETURN: None
*
- * DESCRIPTION: Print "ACPI Exception" message with module/line/version info
- * and decoded ACPI_STATUS.
+ * DESCRIPTION: Print an "ACPI Error" message with module/line/version
+ * info as well as decoded ACPI_STATUS.
*
******************************************************************************/